const React = require('react')
const TopPanel = require('./js/nav-top')
const MiddlePanel = require('./js/nav-middle')
const BottomPanel = require('./js/nav-bottom')
const Background = require('./js/background')

class Nav extends React.Component {
  constructor (props) {
    super(props)

    this.state = {
      isMobile: this.props.isMobile || false,
      isOpen: false,
      activeSection: -1,
      breakpoint: 895
    }

    this.env = this.props.environment || 'com'

    this.toggle = this.toggle.bind(this)
    this.setActiveSection = this.setActiveSection.bind(this)
    this.onResize = this.onResize.bind(this)
    this.setNavOffset = this.setNavOffset.bind(this)
    this.resetNav = this.resetNav.bind(this)
  }

  componentDidMount () {
    this.onResize()
    window.addEventListener('resize', this.onResize)
    window.addEventListener('scroll', this.setNavOffset)
  }

  onResize () {
    const {isMobile, breakpoint} = this.state
    const {innerWidth} = window
    
    if (isMobile && innerWidth > breakpoint) {
      this.setState({ isMobile: false, isOpen: false, activeSection: -1 }, () => {
          this.resetNav()
      })
      document.body.classList.remove('no-scroll')
    } else if (!isMobile && innerWidth <= breakpoint) {
      this.setState({ isMobile: true, activeSection: -1 }, () => {
          this.setNavOffset()
      })
    }
  }

  setNavOffset () {
    if (!this.props.isTopNavHidden && !this.props.disableMobileNavOffset && this.state.isMobile) {
      const nav = document.querySelector('.m-nav').style
      const navBG = document.querySelector('.m-nav-bg').style
      if (window.pageYOffset <= 45) {
        nav.top = `-${window.pageYOffset}px`
        navBG.top = `-${window.pageYOffset}px`
        navBG.height = `calc(100% - ${95 - window.pageYOffset}px)`
      } else {
        nav.top = '-45px'
        navBG.top = '-45px'
        navBG.height = 'calc(100% - 50px)'
      }
    }
  }

  resetNav () {
    if (!this.props.isTopNavHidden && !this.props.disableMobileNavOffset) {
      const nav = document.querySelector('.m-nav').style
      const navBG = document.querySelector('.m-nav-bg').style
      nav.top = '0px'
      navBG.top = '0px'
      navBG.height = '600px'
    }
  }

  setActiveSection (activeSection) {
    this.setState({
      activeSection: activeSection,
      isOpen: activeSection > -1
    })
  }

  toggle () {
    const isOpen = !this.state.isOpen

    if (this.state.isMobile) {
      document.body.classList.toggle('no-scroll', isOpen)
    }

    this.setState({ isOpen })
  }

  render () {
    const active = this.state.activeSection
    const mobile = this.state.isMobile

    return <nav
      style={this.props.isTopNavHidden ? { top: '-45px' } : null}
      className='m-nav m-nav-flex-y'>
      <TopPanel
        downloadUrl={this.props.downloadUrl}
        downloadJmpValue={this.props.downloadJmpValue}
        includeSearch={this.props.includeSearch}
        host={this.env === 'com' ? '' : 'https://www.mongodb.com'}
        sections={this.props.topSections}
        searchUrl={this.props.searchUrl}
        contactUrl={this.props.contactUrl} />
      <MiddlePanel
        activeSection={active}
        isMobile={mobile}
        logoUrl={this.props.logoUrl}
        tagline={this.props.tagline}
        logoLink={this.props.logoLink}
        sections={this.props.sections}
        toggle={this.toggle}
        setActiveSection={this.setActiveSection} />
      <Background
        isMobile={mobile}
        setActiveSection={this.setActiveSection}
        isOpaque={this.state.isOpen || active !== -1 || this.props.isOpaque}
        isOpen={this.state.isOpen}
        isTopNavHidden={this.props.isTopNavHidden}>
        <BottomPanel
          isMobile={mobile}
          activeSection={active}
          midSections={this.props.sections}
          sections={this.props.subsections} />
      </Background>
    </nav>
  }
}

module.exports = Nav
